
;;;----------------------------------------------------------------------
;;; Example 3f
;;; string - felted strike - connected to piano soundboard
;;;----------------------------------------------------------------------

(new)
(multi)
(set-sample-rate 44100)

;;;----------------------------------------------------------------------
;;; objects
;;;----------------------------------------------------------------------

;;; measured modal data of a real piano ---------------------------------

(defvar my-soundboard)
(setq my-soundboard 
      (make-object 'read-from-file "/Volumes/DataStor/_Vorlesungen_Seminare/physical_modeling/resources/def_files/piano-soundboard.txt"))

(defvar my-string)
(setq my-string (make-object 'mono-string
                             (length      1.5)
                             (radius     1e-3)
                             (tension     400)
                             (density    5000)
                             (young      1e10)
                             (freq-loss  0.01)
                             (const-loss  0.4)
                             ))

(defvar my-hammer)
(setq my-hammer (make-object 'bi-two-mass))

;;;----------------------------------------------------------------------
;;; accesses and connections
;;;----------------------------------------------------------------------

(defvar my-string-hit)
(setq my-string-hit (make-access my-string (const .15) 'trans0))
(defvar my-string-plate)
(setq my-string-plate (make-access my-string (const .95) 'trans0))

(defvar my-soundboard-string)
(setq my-soundboard-string (make-access my-soundboard (const .25 .6) 'normal))
(defvar my-hammer-hit)
(setq my-hammer-hit (make-access my-hammer (const 1) 'trans0))

    
(make-connection 'felt my-hammer-hit .1  my-string-hit 0 
                   (const .01)     ;; thickness
                   (const 1e+9)     ;;  F0
                   (const 2.5)      ;;  alpha
                   (const 0.83)     ;;  epsilon
                   (const 35e-04))  ;;  tau
                   
  

;;;----------------------------------------------------------------------
;;; position connection for the hammer
;;;----------------------------------------------------------------------

(defvar my-hammer-mov)
(setq my-hammer-mov (make-access my-hammer (const 0) 'trans0))

(make-connection 'position my-hammer-mov
                 (make-controller 'envelope 1
                                  (list (list 0.00   .1)
                                        (list 0.05  -.001)
                                        (list 0.10   .1)
                                        (list 0.50   .1)
                                        (list 0.55   .1)
                                        (list 0.60   .1))))

;;;----------------------------------------------------------------------
;;; listening points
;;;----------------------------------------------------------------------

;;; listening points on string ------------------------------------------

(defvar my-string-out)
(setq my-string-out (make-access my-string (const .75) 'trans0))

;;; weighted output of 1/100 --------------------------------------------

(make-point-output my-string-out  0 1 (const .01))

;;; listening points on the soundboard using lists-----------------------
;;; list of acceses on the soundboard -----------------------------------

(defvar my-soundboard-acc-list)
(setq my-soundboard-acc-list '((const .1 .1) 
                               (const .3 .3) 
                               (const .4 .3) 
                               (const .6 .7)
                               (const .8 .5) 
                               (const .2 .2) 
                               (const .4 .4) 
                               (const .9 .8)))

;;; list of output points ------------------------------------------------

(defvar my-soundboard-out)
(setq my-soundboard-out (make-access my-soundboard 
                           (eval (nth 0 my-soundboard-acc-list)) 'normal))

(defvar my-soundboard-out-list)
(setq my-soundboard-out-list (list my-soundboard-out))

;;; listening to various points on the soundboard with a weight of 20 ----

(dotimes (i (length my-soundboard-acc-list))
  (make-point-output 
   	(make-access my-soundboard 
      (eval (nth i my-soundboard-acc-list)) 'normal) 
  	0 (const 20)))

;;;----------------------------------------------------------------------
;;; run the synthesis and play the sound
;;;----------------------------------------------------------------------

(run 5)
(play)