
;;;----------------------------------------------------------------------
;;; Example 4a
;;; simple reed instrument
;;;----------------------------------------------------------------------

(new)
(multi)
(set-sample-rate 44100)

(defun midi2hz (x) (* 440 (expt 2 (/ (- x 69) 12))))

;;;----------------------------------------------------------------------
;;; objects
;;;----------------------------------------------------------------------

(defvar my-tube)
(setq my-tube (make-object 'closed-open-tube
               	(modes 160)
				(length 1)
				(air-elasticity 7.14e-06)               				(radius0 0.01)
               	(radius1 0.01)))

(set-pitch my-tube 'length (midi2hz 60))

(defvar my-reed)
(setq my-reed (make-object 'rect-plate
                           (modes       160)
                           (length0   .7e-2) 
                           (length1    2e-2) 
                           (thickness  2e-5)
                           (density     700)
                           (freq-loss   400)
                           (const-loss  200)))
                        
;;;----------------------------------------------------------------------
;;; controllers
;;;----------------------------------------------------------------------

(defvar breath-env)
(setq breath-env (make-controller 'envelope 1							(list 	(list 0.00   0)
            					(list 0.1 3000)
          						(list 0.5  2000)
								(list 9.7 00)
								(list 10 0))))

;;;----------------------------------------------------------------------
;;; access 
;;;----------------------------------------------------------------------

(defvar my-tube-top)
(setq my-tube-top (make-access my-tube (const 0) 'long))
(defvar my-tube-out)
(setq my-tube-out (make-access my-tube (const .90) 'long))

(defvar my-reed-tip)
(setq my-reed-tip (make-access my-reed (const .1 .5) 'normal))

;;;----------------------------------------------------------------------
;;; connections
;;;----------------------------------------------------------------------

(make-connection 'reed my-tube-top my-reed-tip 0.001 
        			breath-env   		    ; breath
                 		(const 1.4)     	; air density
                 		(const 0.0012)   	; reed area
                 		(const 0.01))     	; reed aperture

;;;----------------------------------------------------------------------
;;; listening point on tube
;;;----------------------------------------------------------------------

(make-point-output my-tube-out)

;;;----------------------------------------------------------------------
;;; run the synthesis and play the sound
;;;----------------------------------------------------------------------

(run 12)
(play)
